@@ -29,6 +29,7 @@ import static org.powermock.api.mockito.PowerMockito.mock;
 import static org.powermock.api.mockito.PowerMockito.mockStatic;
 import static org.powermock.api.mockito.PowerMockito.when;
 
+import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.lang.reflect.InvocationTargetException;
@@ -55,6 +56,8 @@ import org.junit.runner.RunWith;
 import org.powermock.core.classloader.annotations.PrepareForTest;
 import org.powermock.modules.junit4.PowerMockRunner;
 
+import com.puppycrawl.tools.checkstyle.api.AuditListener;
+import com.puppycrawl.tools.checkstyle.api.AutomaticBean;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
 import com.puppycrawl.tools.checkstyle.api.LocalizedMessage;
@@ -65,45 +68,62 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
 @PrepareForTest({Main.class, CommonUtil.class})
 public class MainTest {
 
+    private static final String SHORT_USAGE = String.format(Locale.ROOT,
+            "Usage: checkstyle [OPTIONS]... FILES...%n"
+            + "Try 'checkstyle --help' for more information.%n");
+
     private static final String USAGE = String.format(Locale.ROOT,
-          "usage: java com.puppycrawl.tools.checkstyle.Main [options] -c <config.xml>"
-        + " file...%n"
-        + " -c <arg>                                Sets the check configuration file to use.%n"
-        + " -C,--checker-threads-number <arg>       (experimental) The number of Checker threads "
-        + "(must be%n"
-        + "                                         greater than zero)%n"
-        + " -d,--debug                              Print all debug logging of CheckStyle utility%n"
-        + " -e,--exclude <arg>                      Directory path to exclude from CheckStyle%n"
-        + " -executeIgnoredModules                  Allows ignored modules to be run.%n"
-        + " -f <arg>                                Sets the output format. (plain|xml). Defaults"
-        + " to plain%n"
-        + " -gxs,--generate-xpath-suppression       Generates to output a suppression.xml to use to"
-        + " suppress%n"
-        + "                                         all violations from user's config%n"
-        + " -j,--javadocTree                        Print Parse tree of the Javadoc comment%n"
-        + " -J,--treeWithJavadoc                    Print full Abstract Syntax Tree of the file%n"
-        + " -o <arg>                                Sets the output file. Defaults to stdout%n"
-        + " -p <arg>                                Loads the properties file%n"
-        + " -s <arg>                                Print xpath suppressions at the file's line "
-        + "and column%n"
-        + "                                         position. Argument is the line and column "
-        + "number (separated%n"
-        + "                                         by a : ) in the file that the suppression "
-        + "should be%n"
-        + "                                         generated for%n"
-        + " -t,--tree                               Print Abstract Syntax Tree(AST) of the file%n"
-        + " -T,--treeWithComments                   Print Abstract Syntax Tree(AST) of the file"
-        + " including%n"
-        + "                                         comments%n"
-        + " -tabWidth <arg>                         Sets the length of the tab character. "
-        + "Used only with \"-s\"%n"
-        + "                                         option. Default value is 8%n"
-        + " -v                                      Print product version and exit%n"
-        + " -W,--tree-walker-threads-number <arg>   (experimental) The number of TreeWalker threads"
-        + " (must be%n"
-        + "                                         greater than zero)%n"
-        + " -x,--exclude-regexp <arg>               Regular expression of directory to exclude from"
-        + " CheckStyle%n");
+          "Usage: checkstyle [-dghjJtTV] [--executeIgnoredModules] [--tabWidth=<tabWidth>]%n"
+          + "                  [-c=<configurationFile>] [-C=<checkerThreadsNumber>]"
+          + " [-f=<format>]%n"
+          + "                  [-o=<outputPath>] [-p=<propertiesFile>]"
+          + " [-s=<suppressionLineColumnNumber>]%n"
+          + "                  [-W=<treeWalkerThreadsNumber>] [-e=<exclude>]..."
+          + " [-x=<excludeRegex>]... <files>...%n"
+          + "Checkstyle verifies that the specified source code files adhere to the specified"
+          + " rules. By default%n"
+          + "errors are reported to standard out in plain format. Checkstyle requires a"
+          + " configuration XML file%n"
+          + "that configures the checks to apply.%n"
+          + "      <files>...            One or more source files to verify%n"
+          + "      --executeIgnoredModules%n"
+          + "                            Allows ignored modules to be run.%n"
+          + "      --tabWidth=<tabWidth> Sets the length of the tab character. Used only with"
+          + " \"-s\" option. Default%n"
+          + "                              value is 8%n"
+          + "  -c=<configurationFile>    Sets the check configuration file to use.%n"
+          + "  -C, --checker-threads-number=<checkerThreadsNumber>%n"
+          + "                            (experimental) The number of Checker threads (must be"
+          + " greater than zero)%n"
+          + "  -d, --debug               Print all debug logging of CheckStyle utility%n"
+          + "  -e, --exclude=<exclude>   Directory path to exclude from CheckStyle%n"
+          + "  -f=<format>               Sets the output format. Valid values: xml, plain."
+          + " Defaults to plain%n"
+          + "  -g, --generate-xpath-suppression%n"
+          + "                            Generates to output a suppression.xml to use to suppress"
+          + " all violations from%n"
+          + "                              user's config%n"
+          + "  -h, --help                Show this help message and exit.%n"
+          + "  -j, --javadocTree         Print Parse tree of the Javadoc comment%n"
+          + "  -J, --treeWithJavadoc     Print full Abstract Syntax Tree of the file%n"
+          + "  -o=<outputPath>           Sets the output file. Defaults to stdout%n"
+          + "  -p=<propertiesFile>       Loads the properties file%n"
+          + "  -s=<suppressionLineColumnNumber>%n"
+          + "                            Print xpath suppressions at the file's line and column"
+          + " position. Argument is%n"
+          + "                              the line and column number (separated by a : ) in the"
+          + " file that the%n"
+          + "                              suppression should be generated for%n"
+          + "  -t, --tree                Print Abstract Syntax Tree(AST) of the file%n"
+          + "  -T, --treeWithComments    Print Abstract Syntax Tree(AST) of the file including"
+          + " comments%n"
+          + "  -V, --version             Print version information and exit.%n"
+          + "  -W, --tree-walker-threads-number=<treeWalkerThreadsNumber>%n"
+          + "                            (experimental) The number of TreeWalker threads (must be"
+          + " greater than zero)%n"
+          + "  -x, --exclude-regexp=<excludeRegex>%n"
+          + "                            Regular expression of directory to exclude from"
+          + " CheckStyle%n");
 
     private static final Logger LOG = Logger.getLogger(MainTest.class.getName()).getParent();
     private static final Handler[] HANDLERS = LOG.getHandlers();
@@ -181,7 +201,19 @@ public class MainTest {
                     systemOut.getLog());
             assertEquals("Unexpected system error log", "", systemErr.getLog());
         });
-        Main.main("-v");
+        Main.main("-V");
+    }
+
+    @Test
+    public void testUsageHelpPrint()
+            throws Exception {
+        exit.checkAssertionAfterwards(() -> {
+            assertEquals("Unexpected output log",
+                    USAGE,
+                    systemOut.getLog());
+            assertEquals("Unexpected system error log", "", systemErr.getLog());
+        });
+        Main.main("-h");
     }
 
     @Test
@@ -189,10 +221,28 @@ public class MainTest {
             throws Exception {
         exit.expectSystemExitWithStatus(-1);
         exit.checkAssertionAfterwards(() -> {
-            final String usage = "Unrecognized option: -w" + EOL
-                    + USAGE;
-            assertEquals("Unexpected output log", usage, systemOut.getLog());
-            assertEquals("Unexpected system error log", "", systemErr.getLog());
+            final String usage = "Unknown option: -w" + EOL
+                    + SHORT_USAGE;
+            assertEquals("Unexpected output log", "", systemOut.getLog());
+            assertEquals("Unexpected system error log", usage, systemErr.getLog());
+        });
+        // need to specify a file:
+        // <files> is defined as a required positional param;
+        // picocli verifies required parameters before checking unknown options
+        Main.main("-w", "file");
+    }
+
+    @Test
+    public void testWrongArgumentMissingFiles()
+            throws Exception {
+        exit.expectSystemExitWithStatus(-1);
+        exit.checkAssertionAfterwards(() -> {
+            // files is defined as a required positional param;
+            // picocli verifies required parameters before checking unknown options
+            final String usage = "Missing required parameter: <files>" + EOL
+                    + SHORT_USAGE;
+            assertEquals("Unexpected output log", "", systemOut.getLog());
+            assertEquals("Unexpected system error log", usage, systemErr.getLog());
         });
         Main.main("-w");
     }
@@ -240,9 +290,10 @@ public class MainTest {
     public void testNonExistentOutputFormat() throws Exception {
         exit.expectSystemExitWithStatus(-1);
         exit.checkAssertionAfterwards(() -> {
-            assertEquals("Unexpected output log", "Invalid output format. "
-                    + "Found 'xmlp' but expected 'plain' or 'xml'." + EOL, systemOut.getLog());
-            assertEquals("Unexpected system error log", "", systemErr.getLog());
+            assertEquals("Unexpected output log", "", systemOut.getLog());
+            assertEquals("Unexpected system error log",
+                    "Invalid value for option '-f': expected one of [xml, plain] but was 'xmlp'"
+                    + EOL + SHORT_USAGE, systemErr.getLog());
         });
         Main.main("-c", "/google_checks.xml", "-f", "xmlp",
                 getPath("InputMain.java"));
@@ -362,6 +413,37 @@ public class MainTest {
                 getPath("InputMain.java"));
     }
 
+    /**
+     * Similar test to {@link #testExistingTargetFileWithError}, but for PIT mutation tests:
+     * this test fails if the boundary condition is changed from {@code if (exitStatus > 0)}
+     * to {@code if (exitStatus > 1)}.
+     * @throws Exception should not throw anything
+     */
+    @Test
+    public void testExistingTargetFileWithOneError()
+            throws Exception {
+        exit.expectSystemExitWithStatus(1);
+        exit.checkAssertionAfterwards(() -> {
+            final LocalizedMessage errorCounterTwoMessage = new LocalizedMessage(1,
+                    Definitions.CHECKSTYLE_BUNDLE, Main.ERROR_COUNTER,
+                    new String[] {String.valueOf(1)}, null, getClass(), null);
+            final LocalizedMessage invalidPatternMessageMain = new LocalizedMessage(1,
+                    "com.puppycrawl.tools.checkstyle.checks.naming.messages",
+                    "name.invalidPattern", new String[] {"InputMain1", "^[a-z0-9]*$"},
+                    null, getClass(), null);
+            final String expectedPath = getFilePath("InputMain1.java");
+            assertEquals("Unexpected output log", auditStartMessage.getMessage() + EOL
+                    + "[ERROR] " + expectedPath + ":3:14: "
+                    + invalidPatternMessageMain.getMessage() + " [TypeName]" + EOL
+                    + auditFinishMessage.getMessage() + EOL
+                    + errorCounterTwoMessage.getMessage() + EOL, systemOut.getLog());
+            assertEquals("Unexpected system error log", "", systemErr.getLog());
+        });
+        Main.main("-c",
+                getPath("InputMainConfig-classname2-error.xml"),
+                getPath("InputMain1.java"));
+    }
+
     @Test
     public void testExistentTargetFilePlainOutputToNonExistentFile()
             throws Exception {
@@ -478,7 +560,8 @@ public class MainTest {
     public void testLoadPropertiesIoException() throws Exception {
         final Class<?>[] param = new Class<?>[1];
         param[0] = File.class;
-        final Method method = Main.class.getDeclaredMethod("loadProperties", param);
+        final Class<?> cliOptionsClass = Class.forName(Main.class.getName());
+        final Method method = cliOptionsClass.getDeclaredMethod("loadProperties", param);
         method.setAccessible(true);
         try {
             method.invoke(null, new File("."));
@@ -508,26 +591,6 @@ public class MainTest {
         }
     }
 
-    @Test
-    public void testCreateListenerIllegalStateException() throws Exception {
-        final Method method = Main.class.getDeclaredMethod("createListener", String.class,
-            String.class);
-        method.setAccessible(true);
-        try {
-            method.invoke(null, "myformat", null);
-            fail("InvocationTargetException is expected");
-        }
-        catch (InvocationTargetException ex) {
-            final LocalizedMessage loadPropertiesMessage = new LocalizedMessage(1,
-                    Definitions.CHECKSTYLE_BUNDLE, Main.CREATE_LISTENER_EXCEPTION,
-                    new String[] {"myformat", "plain", "xml"}, null, getClass(), null);
-            assertEquals("Invalid error message",
-                    loadPropertiesMessage.getMessage(), ex.getCause().getLocalizedMessage());
-            assertTrue("Invalid error cause",
-                    ex.getCause() instanceof IllegalStateException);
-        }
-    }
-
     @Test
     public void testExistingDirectoryWithViolations() throws Exception {
         // we just reference there all violations
@@ -566,7 +629,8 @@ public class MainTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testListFilesNotFile() throws Exception {
-        final Method method = Main.class.getDeclaredMethod("listFiles", File.class, List.class);
+        final Class<?> optionsClass = Class.forName(Main.class.getName());
+        final Method method = optionsClass.getDeclaredMethod("listFiles", File.class, List.class);
         method.setAccessible(true);
 
         final File fileMock = mock(File.class);
@@ -581,7 +645,8 @@ public class MainTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testListFilesDirectoryWithNull() throws Exception {
-        final Method method = Main.class.getDeclaredMethod("listFiles", File.class, List.class);
+        final Class<?> optionsClass = Class.forName(Main.class.getName());
+        final Method method = optionsClass.getDeclaredMethod("listFiles", File.class, List.class);
         method.setAccessible(true);
 
         final File fileMock = mock(File.class);
@@ -708,11 +773,12 @@ public class MainTest {
     public void testPrintTreeJavadocOption() throws Exception {
         final String expected = new String(Files.readAllBytes(Paths.get(
             getPath("InputMainExpectedInputJavadocComment.txt"))), StandardCharsets.UTF_8)
-            .replaceAll("\\\\r\\\\n", "\\\\n");
+            .replaceAll("\\\\r\\\\n", "\\\\n").replaceAll("\r\n", "\n");
 
         exit.checkAssertionAfterwards(() -> {
             assertEquals("Unexpected output log",
-                    expected, systemOut.getLog().replaceAll("\\\\r\\\\n", "\\\\n"));
+                    expected, systemOut.getLog().replaceAll("\\\\r\\\\n", "\\\\n")
+                            .replaceAll("\r\n", "\n"));
             assertEquals("Unexpected system error log",
                     "", systemErr.getLog());
         });
@@ -754,7 +820,7 @@ public class MainTest {
                     "", systemErr.getLog());
         });
         Main.main(getPath("InputMainSuppressionsStringPrinter.java"),
-                "-s", "7:9", "-tabWidth", "2");
+                "-s", "7:9", "--tabWidth", "2");
     }
 
     @Test
@@ -1012,7 +1078,7 @@ public class MainTest {
         });
         Main.main("-c", getPath("InputMainConfig-xpath-suppressions.xml"),
                 "--generate-xpath-suppression",
-                "-tabWidth", "20",
+                "--tabWidth", "20",
                 getPath("InputMainGenerateXpathSuppressionsTabWidth.java"));
     }
 
@@ -1020,11 +1086,13 @@ public class MainTest {
     public void testPrintFullTreeOption() throws Exception {
         final String expected = new String(Files.readAllBytes(Paths.get(
             getPath("InputMainExpectedInputAstTreeStringPrinterJavadoc.txt"))),
-            StandardCharsets.UTF_8).replaceAll("\\\\r\\\\n", "\\\\n");
+            StandardCharsets.UTF_8).replaceAll("\\\\r\\\\n", "\\\\n")
+                .replaceAll("\r\n", "\n");
 
         exit.checkAssertionAfterwards(() -> {
             assertEquals("Unexpected output log",
-                    expected, systemOut.getLog().replaceAll("\\\\r\\\\n", "\\\\n"));
+                    expected, systemOut.getLog().replaceAll("\\\\r\\\\n", "\\\\n")
+                            .replaceAll("\r\n", "\n"));
             assertEquals("Unexpected system error log", "", systemErr.getLog());
         });
         Main.main("-J", getPath("InputMainAstTreeStringPrinterJavadoc.java"));
@@ -1126,7 +1194,8 @@ public class MainTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testExcludeDirectoryNotMatch() throws Exception {
-        final Method method = Main.class.getDeclaredMethod("listFiles", File.class, List.class);
+        final Class<?> optionsClass = Class.forName(Main.class.getName());
+        final Method method = optionsClass.getDeclaredMethod("listFiles", File.class, List.class);
         method.setAccessible(true);
         final List<Pattern> list = new ArrayList<>();
         list.add(Pattern.compile("BAD_PATH"));
@@ -1188,7 +1257,7 @@ public class MainTest {
         });
 
         Main.main("-c", getPath("InputMainConfig-non-existent-classname-ignore.xml"),
-                "-executeIgnoredModules",
+                "--executeIgnoredModules",
                 getPath("InputMain.java"));
     }
 
@@ -1196,9 +1265,10 @@ public class MainTest {
     public void testInvalidCheckerThreadsNumber() throws Exception {
         exit.expectSystemExitWithStatus(-1);
         exit.checkAssertionAfterwards(() -> {
-            assertEquals("Unexpected output log", "Invalid Checker threads number"
-                + System.lineSeparator(), systemOut.getLog());
-            assertEquals("Unexpected system error log", "", systemErr.getLog());
+            assertEquals("Unexpected output log", "", systemOut.getLog());
+            assertEquals("Unexpected system error log",
+                    "Invalid value for option '--checker-threads-number': 'invalid' is not an int"
+                    + EOL + SHORT_USAGE, systemErr.getLog());
         });
         Main.main("-C", "invalid", "-c", "/google_checks.xml", getPath("InputMain.java"));
     }
@@ -1207,9 +1277,10 @@ public class MainTest {
     public void testInvalidTreeWalkerThreadsNumber() throws Exception {
         exit.expectSystemExitWithStatus(-1);
         exit.checkAssertionAfterwards(() -> {
-            assertEquals("Unexpected output log", "Invalid TreeWalker threads number"
-                + System.lineSeparator(), systemOut.getLog());
-            assertEquals("Unexpected system error log", "", systemErr.getLog());
+            assertEquals("Unexpected output log", "", systemOut.getLog());
+            assertEquals("Unexpected system error log",
+                    "Invalid value for option '--tree-walker-threads-number': "
+                    + "'invalid' is not an int" + EOL + SHORT_USAGE, systemErr.getLog());
         });
         Main.main("-W", "invalid", "-c", "/google_checks.xml", getPath("InputMain.java"));
     }
@@ -1329,12 +1400,44 @@ public class MainTest {
      */
     @Test
     public void testJacocoWorkaround() throws Exception {
-        final String expected = "Files to process must be specified, found 0."
-            + System.lineSeparator();
+        final String expected = "Missing required parameter: <files>" + EOL + SHORT_USAGE;
         mockStatic(System.class);
         Main.main();
-        assertEquals("Unexpected output log", expected, systemOut.getLog());
-        assertEquals("Unexpected system error log", "", systemErr.getLog());
+        assertEquals("Unexpected output log", "", systemOut.getLog());
+        assertEquals("Unexpected system error log", expected, systemErr.getLog());
+    }
+
+    @Test
+    public void testMissingFiles() throws Exception {
+        exit.expectSystemExitWithStatus(-1);
+        exit.checkAssertionAfterwards(() -> {
+            final String usage = "Missing required parameter: <files>" + EOL + SHORT_USAGE;
+            assertEquals("Unexpected output log", "", systemOut.getLog());
+            assertEquals("Unexpected system error log", usage, systemErr.getLog());
+        });
+        Main.main();
+    }
+
+    @Test
+    public void testOutputFormatToStringLowercase() {
+        assertEquals("expected xml", "xml", Main.OutputFormat.XML.toString());
+        assertEquals("expected plain", "plain", Main.OutputFormat.PLAIN.toString());
+    }
+
+    @Test
+    public void testXmlOutputFormatCreateListener() {
+        final ByteArrayOutputStream out = new ByteArrayOutputStream();
+        final AuditListener listener = Main.OutputFormat.XML.createListener(out,
+                AutomaticBean.OutputStreamOptions.CLOSE);
+        assertTrue("listener is XMLLogger", listener instanceof XMLLogger);
+    }
+
+    @Test
+    public void testPlainOutputFormatCreateListener() {
+        final ByteArrayOutputStream out = new ByteArrayOutputStream();
+        final AuditListener listener = Main.OutputFormat.PLAIN.createListener(out,
+                AutomaticBean.OutputStreamOptions.CLOSE);
+        assertTrue("listener is DefaultLogger", listener instanceof DefaultLogger);
     }
 
 }
