@@ -46,6 +46,7 @@ import com.puppycrawl.tools.checkstyle.checks.naming.ConstantNameCheck;
 import com.puppycrawl.tools.checkstyle.checks.naming.MemberNameCheck;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
 import nl.jqno.equalsverifier.EqualsVerifier;
+import nl.jqno.equalsverifier.EqualsVerifierReport;
 
 public class SuppressWithNearbyCommentFilterTest
     extends AbstractModuleTestSupport {
@@ -286,7 +287,9 @@ public class SuppressWithNearbyCommentFilterTest
 
     @Test
     public void testEqualsAndHashCodeOfTagClass() {
-        EqualsVerifier.forClass(SuppressWithNearbyCommentFilter.Tag.class).usingGetClass().verify();
+        final EqualsVerifierReport ev = EqualsVerifier
+                .forClass(SuppressWithNearbyCommentFilter.Tag.class).usingGetClass().report();
+        assertEquals("Error: " + ev.getMessage(), EqualsVerifierReport.SUCCESS, ev);
     }
 
     private void verifySuppressed(Configuration moduleConfig,
